@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '5.011';
+our $VERSION = '5.012';
 
 sub new {
     my ($class) = @_;
@@ -95,10 +95,10 @@ sub PT::Group::X {
 sub PT::NonSyntaxClass::X {
     my ($class, $className) = @_;
     my $nonSyntax = $class->{''};
-    
+
     my @nonSyntax = split(" ", $nonSyntax);
     $nonSyntax = $nonSyntax[0];
-    
+
     print "SyntaxError", "\n";
     print "===========", "\n";
     print "ClassName: ", $className, "\n";
@@ -382,18 +382,18 @@ sub PT::Block::X {
 sub PT::NonSyntaxFunction::X {
     my ($class, $className, $functionName) = @_;
     my $nonSyntax = $class->{''};
-    
+
     my @nonSyntax = split(" ", $nonSyntax);
     $nonSyntax = $nonSyntax[0];
 
     print "SyntaxError", "\n";
     print "===========", "\n";
     print "ClassName: ", $className, "\n";
-    
-    if(defined $functionName) { 
+
+    if(defined $functionName) {
     	print "FunctionName: ", $functionName, "\n";
     }
-    
+
     die "Error: $nonSyntax \n";
 }
 
@@ -911,7 +911,7 @@ sub PT::Assignment::X {
 sub PT::AccessorAssignment::X {
     my ($class, $className) = @_;
 
-    my $variableName = $class->{String}->X($className);
+    my $variableName = $class->{ScalarVariable}->X($className);
     my $rhs = $class->{RHS}->X($className);
 
     my $accessorAssignment  = '$class->{"' . $className . '"}->{"'. $variableName .'"} = ' . $rhs .';';
@@ -987,7 +987,7 @@ sub PT::ObjectFunctionCall::X {
 
 sub PT::ClassAccessor::X {
     my ($class, $className) = @_;
-    my $variableName = $class->{String}->X($className);
+    my $variableName = $class->{ScalarVariable}->X($className);
 
     my $classAccessor = '$class->{"' . $className . '"}->{"'. $variableName .'"}';
     return $classAccessor;
@@ -1325,7 +1325,7 @@ sub PT::LogicalOr::X {
 
 my $parser = qr {
     <nocontext:>
-    <debug: off>
+    <debug: on>
 
     <Lang>
     <objrule:  PT::Lang>                       <[Class]>+
@@ -1480,8 +1480,8 @@ my $parser = qr {
 
     <objrule:  PT::STDIN>                      <LessThan>  <TokenSTDIN> <GreaterThan>
 
-    <objrule:  PT::AccessorAssignment>         <TokenClass> <Dot> <String> <Equal> <RHS> <SemiColon>
-    <objrule:  PT::ClassAccessor>              <TokenClass> <Dot> <String>
+    <objrule:  PT::AccessorAssignment>         <TokenClass> <Dot> <ScalarVariable> <Equal> <RHS> <SemiColon>
+    <objrule:  PT::ClassAccessor>              <TokenClass> <Dot> <ScalarVariable>
     <objrule:  PT::ClassFunctionReturn>        <TokenClass> <Dot> <FunctionName> <LParen> <Parameters>? <RParen>
 
     <objrule:  PT::ArrayAssignment>            <ArrayElement> <Equal> <RHS> <SemiColon>
